@@ -5,7 +5,7 @@
 import logging
 from typing import List, Any, Union
 
-from superbsapi import *
+from superbsapi import CBSHandleLoc
 
 from .BaseDB import BaseDB
 from .exception import DBError, DataError
@@ -100,9 +100,9 @@ class TreeDB(BaseDB):
                 self.exec_tree('Treedb_ReopenMainKey', sub_key, flag, path_flag, main_key, main_key_pwd, file)
             except DBError:
                 try:
-                    logging.warning('正在重新连接数据库并打开主键[%s]-子键[%s]' % (main_key, sub_key))
                     self.__chl = CBSHandleLoc()
                     self.exec_tree('Treedb_Alloc', host, file, main_key, main_key_pwd, TRDB_OPKF_OPENEXIST, port)
+                    logging.warning('正在重新连接数据库并打开主键[%s]-子键[%s]' % (main_key, sub_key))
                     self.exec_tree('Treedb_ReopenSubKey', sub_key, flag)
                 except DBError as e:
                     raise DBError(e.err_code, '打开主键[%s]-子键[%s]时' % (main_key, sub_key))
@@ -114,9 +114,9 @@ class TreeDB(BaseDB):
                     self.exec_tree('Treedb_ReopenMainKey', '', flag, path_flag, main_key, main_key_pwd, file)
                 except DBError:
                     try:
-                        logging.warning('正在重新连接数据库并打开主键[%s]' % main_key)
                         self.__chl = CBSHandleLoc()
                         self.exec_tree('Treedb_Alloc', host, file, main_key, main_key_pwd, TRDB_OPKF_OPENEXIST, port)
+                        logging.warning('正在重新连接tree数据库并打开主键[%s]' % main_key)
                     except DBError as e:
                         raise DBError(e.err_code, '打开主键[%s]时' % main_key)
         return self
@@ -254,7 +254,7 @@ class TreeDB(BaseDB):
         :param overwrite: 是否覆盖原值
         """
 
-        return self.exec_bs('bs_treedb_insert_propertys', self._generation_items(items), overwrite)
+        return self.exec_bs('bs_treedb_insert_propertys', self._generation_items(items), overwrite) if items else 0
 
     def insert_key_items(self, items: Union[List[tuple], dict], key: str = None) -> str:
         """
@@ -270,7 +270,7 @@ class TreeDB(BaseDB):
         """
 
         return self.exec_bs('bs_treedb_insert_key_and_properties', key or '', TRDB_OPKF_OPENEXIST,
-                            self._generation_items(items), True)
+                            self._generation_items(items), True) if items else 0
 
     def delete(self, keys: Union[list, str, None] = None) -> None:
         """
